==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/BlobEventsTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.BlobEventsTriggerArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.BlobEventTypes
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Trigger that runs every time a Blob event occurs.
 * @property annotations List of tags that can be used for describing the trigger.
 * @property blobPathBeginsWith The blob path must begin with the pattern provided for trigger to fire. For example, '/records/blobs/december/' will only fire the trigger for blobs in the december folder under the records container. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
 * @property blobPathEndsWith The blob path must end with the pattern provided for trigger to fire. For example, 'december/boxes.csv' will only fire the trigger for blobs named boxes in a december folder. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
 * @property description Trigger description.
 * @property events The type of events that cause this trigger to fire.
 * @property ignoreEmptyBlobs If set to true, blobs with zero bytes will be ignored.
 * @property pipelines Pipelines that need to be started.
 * @property scope The ARM resource ID of the Storage Account.
 * @property type Trigger type.
 * Expected value is 'BlobEventsTrigger'.
 */
public data class BlobEventsTriggerArgs(
    public val annotations: Output<List<Any>>? = null,
    public val blobPathBeginsWith: Output<String>? = null,
    public val blobPathEndsWith: Output<String>? = null,
    public val description: Output<String>? = null,
    public val events: Output<List<Either<String, BlobEventTypes>>>,
    public val ignoreEmptyBlobs: Output<Boolean>? = null,
    public val pipelines: Output<List<TriggerPipelineReferenceArgs>>? = null,
    public val scope: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.BlobEventsTriggerArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.BlobEventsTriggerArgs =
        com.pulumi.azurenative.datafactory.inputs.BlobEventsTriggerArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .blobPathBeginsWith(blobPathBeginsWith?.applyValue({ args0 -> args0 }))
            .blobPathEndsWith(blobPathEndsWith?.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .events(
                events.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            )
            .ignoreEmptyBlobs(ignoreEmptyBlobs?.applyValue({ args0 -> args0 }))
            .pipelines(
                pipelines?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .scope(scope.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BlobEventsTriggerArgs].
 */
@PulumiTagMarker
public class BlobEventsTriggerArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var blobPathBeginsWith: Output<String>? = null

    private var blobPathEndsWith: Output<String>? = null

    private var description: Output<String>? = null

    private var events: Output<List<Either<String, BlobEventTypes>>>? = null

    private var ignoreEmptyBlobs: Output<Boolean>? = null

    private var pipelines: Output<List<TriggerPipelineReferenceArgs>>? = null

    private var scope: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("xadyctrftwhonoto")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("npciagaaiqadciyh")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("smjxdhpbvpidywer")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value The blob path must begin with the pattern provided for trigger to fire. For example, '/records/blobs/december/' will only fire the trigger for blobs in the december folder under the records container. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
     */
    @JvmName("dxarxduxiqndaoba")
    public suspend fun blobPathBeginsWith(`value`: Output<String>) {
        this.blobPathBeginsWith = value
    }

    /**
     * @param value The blob path must end with the pattern provided for trigger to fire. For example, 'december/boxes.csv' will only fire the trigger for blobs named boxes in a december folder. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
     */
    @JvmName("emhmhjwqfkycphqp")
    public suspend fun blobPathEndsWith(`value`: Output<String>) {
        this.blobPathEndsWith = value
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("gkypdsnnnvinifyo")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value The type of events that cause this trigger to fire.
     */
    @JvmName("eqhdglmyuwrejnjx")
    public suspend fun events(`value`: Output<List<Either<String, BlobEventTypes>>>) {
        this.events = value
    }

    @JvmName("evogbtbssygwbgsi")
    public suspend fun events(vararg values: Output<Either<String, BlobEventTypes>>) {
        this.events = Output.all(values.asList())
    }

    /**
     * @param values The type of events that cause this trigger to fire.
     */
    @JvmName("afpbajbpbwurtjou")
    public suspend fun events(values: List<Output<Either<String, BlobEventTypes>>>) {
        this.events = Output.all(values)
    }

    /**
     * @param value If set to true, blobs with zero bytes will be ignored.
     */
    @JvmName("mqifomueccfwjarl")
    public suspend fun ignoreEmptyBlobs(`value`: Output<Boolean>) {
        this.ignoreEmptyBlobs = value
    }

    /**
     * @param value Pipelines that need to be started.
     */
    @JvmName("ehidnxidsnfwkrgo")
    public suspend fun pipelines(`value`: Output<List<TriggerPipelineReferenceArgs>>) {
        this.pipelines = value
    }

    @JvmName("vyuykdcqmtydwmgy")
    public suspend fun pipelines(vararg values: Output<TriggerPipelineReferenceArgs>) {
        this.pipelines = Output.all(values.asList())
    }

    /**
     * @param values Pipelines that need to be started.
     */
    @JvmName("aaediybibderceaq")
    public suspend fun pipelines(values: List<Output<TriggerPipelineReferenceArgs>>) {
        this.pipelines = Output.all(values)
    }

    /**
     * @param value The ARM resource ID of the Storage Account.
     */
    @JvmName("rnetmynqpvstglot")
    public suspend fun scope(`value`: Output<String>) {
        this.scope = value
    }

    /**
     * @param value Trigger type.
     * Expected value is 'BlobEventsTrigger'.
     */
    @JvmName("estlqnafgvxqwedr")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("efeplwonnkmmyyhd")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("twqyalleebgqstdx")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value The blob path must begin with the pattern provided for trigger to fire. For example, '/records/blobs/december/' will only fire the trigger for blobs in the december folder under the records container. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
     */
    @JvmName("flcukhsysuqesjky")
    public suspend fun blobPathBeginsWith(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobPathBeginsWith = mapped
    }

    /**
     * @param value The blob path must end with the pattern provided for trigger to fire. For example, 'december/boxes.csv' will only fire the trigger for blobs named boxes in a december folder. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
     */
    @JvmName("gyxleiseshxbshqb")
    public suspend fun blobPathEndsWith(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobPathEndsWith = mapped
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("ryfeabeyclvqcghv")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value The type of events that cause this trigger to fire.
     */
    @JvmName("yqtnagpgenwhlwvg")
    public suspend fun events(`value`: List<Either<String, BlobEventTypes>>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.events = mapped
    }

    /**
     * @param values The type of events that cause this trigger to fire.
     */
    @JvmName("gknqokounalirnxf")
    public suspend fun events(vararg values: Either<String, BlobEventTypes>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.events = mapped
    }

    /**
     * @param value If set to true, blobs with zero bytes will be ignored.
     */
    @JvmName("lvqodjjpjldfthej")
    public suspend fun ignoreEmptyBlobs(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ignoreEmptyBlobs = mapped
    }

    /**
     * @param value Pipelines that need to be started.
     */
    @JvmName("jttdipmjvsurhlxe")
    public suspend fun pipelines(`value`: List<TriggerPipelineReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pipelines = mapped
    }

    /**
     * @param argument Pipelines that need to be started.
     */
    @JvmName("wsoiwdbdxmfftjam")
    public suspend
    fun pipelines(argument: List<suspend TriggerPipelineReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TriggerPipelineReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.pipelines = mapped
    }

    /**
     * @param argument Pipelines that need to be started.
     */
    @JvmName("pbswsyogfkjpdjoh")
    public suspend fun pipelines(
        vararg
        argument: suspend TriggerPipelineReferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TriggerPipelineReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.pipelines = mapped
    }

    /**
     * @param argument Pipelines that need to be started.
     */
    @JvmName("cxbiatkginfqidre")
    public suspend fun pipelines(argument: suspend TriggerPipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            TriggerPipelineReferenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.pipelines = mapped
    }

    /**
     * @param values Pipelines that need to be started.
     */
    @JvmName("buawnqnvgwgsbrvo")
    public suspend fun pipelines(vararg values: TriggerPipelineReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pipelines = mapped
    }

    /**
     * @param value The ARM resource ID of the Storage Account.
     */
    @JvmName("elylxovjbgvkqanj")
    public suspend fun scope(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scope = mapped
    }

    /**
     * @param value Trigger type.
     * Expected value is 'BlobEventsTrigger'.
     */
    @JvmName("hthpssommstpirnj")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): BlobEventsTriggerArgs = BlobEventsTriggerArgs(
        annotations = annotations,
        blobPathBeginsWith = blobPathBeginsWith,
        blobPathEndsWith = blobPathEndsWith,
        description = description,
        events = events ?: throw PulumiNullFieldException("events"),
        ignoreEmptyBlobs = ignoreEmptyBlobs,
        pipelines = pipelines,
        scope = scope ?: throw PulumiNullFieldException("scope"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/BlobEventsTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.BlobEventsTriggerArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.BlobEventTypes
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Trigger that runs every time a Blob event occurs.
 * @property annotations List of tags that can be used for describing the trigger.
 * @property blobPathBeginsWith The blob path must begin with the pattern provided for trigger to fire. For example, '/records/blobs/december/' will only fire the trigger for blobs in the december folder under the records container. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
 * @property blobPathEndsWith The blob path must end with the pattern provided for trigger to fire. For example, 'december/boxes.csv' will only fire the trigger for blobs named boxes in a december folder. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
 * @property description Trigger description.
 * @property events The type of events that cause this trigger to fire.
 * @property ignoreEmptyBlobs If set to true, blobs with zero bytes will be ignored.
 * @property pipelines Pipelines that need to be started.
 * @property scope The ARM resource ID of the Storage Account.
 * @property type Trigger type.
 * Expected value is 'BlobEventsTrigger'.
 */
public data class BlobEventsTriggerArgs(
    public val annotations: Output<List<Any>>? = null,
    public val blobPathBeginsWith: Output<String>? = null,
    public val blobPathEndsWith: Output<String>? = null,
    public val description: Output<String>? = null,
    public val events: Output<List<Either<String, BlobEventTypes>>>,
    public val ignoreEmptyBlobs: Output<Boolean>? = null,
    public val pipelines: Output<List<TriggerPipelineReferenceArgs>>? = null,
    public val scope: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.BlobEventsTriggerArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.BlobEventsTriggerArgs =
        com.pulumi.azurenative.datafactory.inputs.BlobEventsTriggerArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .blobPathBeginsWith(blobPathBeginsWith?.applyValue({ args0 -> args0 }))
            .blobPathEndsWith(blobPathEndsWith?.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .events(
                events.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            )
            .ignoreEmptyBlobs(ignoreEmptyBlobs?.applyValue({ args0 -> args0 }))
            .pipelines(
                pipelines?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .scope(scope.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BlobEventsTriggerArgs].
 */
@PulumiTagMarker
public class BlobEventsTriggerArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var blobPathBeginsWith: Output<String>? = null

    private var blobPathEndsWith: Output<String>? = null

    private var description: Output<String>? = null

    private var events: Output<List<Either<String, BlobEventTypes>>>? = null

    private var ignoreEmptyBlobs: Output<Boolean>? = null

    private var pipelines: Output<List<TriggerPipelineReferenceArgs>>? = null

    private var scope: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("xsomhgniqihkwtsi")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("eogiycsylsimtcat")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("rmqnfqtocmnnwdrp")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value The blob path must begin with the pattern provided for trigger to fire. For example, '/records/blobs/december/' will only fire the trigger for blobs in the december folder under the records container. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
     */
    @JvmName("ambudhuhaasbpmee")
    public suspend fun blobPathBeginsWith(`value`: Output<String>) {
        this.blobPathBeginsWith = value
    }

    /**
     * @param value The blob path must end with the pattern provided for trigger to fire. For example, 'december/boxes.csv' will only fire the trigger for blobs named boxes in a december folder. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
     */
    @JvmName("ouodcxdfrebuplea")
    public suspend fun blobPathEndsWith(`value`: Output<String>) {
        this.blobPathEndsWith = value
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("urpirsyfbttgbbir")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value The type of events that cause this trigger to fire.
     */
    @JvmName("qgfrdbquxwblkyox")
    public suspend fun events(`value`: Output<List<Either<String, BlobEventTypes>>>) {
        this.events = value
    }

    @JvmName("lubetcpwgdsjridk")
    public suspend fun events(vararg values: Output<Either<String, BlobEventTypes>>) {
        this.events = Output.all(values.asList())
    }

    /**
     * @param values The type of events that cause this trigger to fire.
     */
    @JvmName("pahjrdpyxhljwygo")
    public suspend fun events(values: List<Output<Either<String, BlobEventTypes>>>) {
        this.events = Output.all(values)
    }

    /**
     * @param value If set to true, blobs with zero bytes will be ignored.
     */
    @JvmName("akxykcbqinrxultf")
    public suspend fun ignoreEmptyBlobs(`value`: Output<Boolean>) {
        this.ignoreEmptyBlobs = value
    }

    /**
     * @param value Pipelines that need to be started.
     */
    @JvmName("ilirkftcojlgdxok")
    public suspend fun pipelines(`value`: Output<List<TriggerPipelineReferenceArgs>>) {
        this.pipelines = value
    }

    @JvmName("dabkddirjmiyyidm")
    public suspend fun pipelines(vararg values: Output<TriggerPipelineReferenceArgs>) {
        this.pipelines = Output.all(values.asList())
    }

    /**
     * @param values Pipelines that need to be started.
     */
    @JvmName("nuxwagwfewqkdnar")
    public suspend fun pipelines(values: List<Output<TriggerPipelineReferenceArgs>>) {
        this.pipelines = Output.all(values)
    }

    /**
     * @param value The ARM resource ID of the Storage Account.
     */
    @JvmName("aumaojffnknwjxeu")
    public suspend fun scope(`value`: Output<String>) {
        this.scope = value
    }

    /**
     * @param value Trigger type.
     * Expected value is 'BlobEventsTrigger'.
     */
    @JvmName("blpiwygkbbacbvff")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("pvblwbawheudvdpm")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("dvqtydkrjfvkxnsq")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value The blob path must begin with the pattern provided for trigger to fire. For example, '/records/blobs/december/' will only fire the trigger for blobs in the december folder under the records container. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
     */
    @JvmName("utdjdxdrmyfhwtdo")
    public suspend fun blobPathBeginsWith(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobPathBeginsWith = mapped
    }

    /**
     * @param value The blob path must end with the pattern provided for trigger to fire. For example, 'december/boxes.csv' will only fire the trigger for blobs named boxes in a december folder. At least one of these must be provided: blobPathBeginsWith, blobPathEndsWith.
     */
    @JvmName("uuwjpcuvmaaqcuad")
    public suspend fun blobPathEndsWith(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobPathEndsWith = mapped
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("talhgcdvqqhnccai")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value The type of events that cause this trigger to fire.
     */
    @JvmName("owcaocphbqtsurxe")
    public suspend fun events(`value`: List<Either<String, BlobEventTypes>>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.events = mapped
    }

    /**
     * @param values The type of events that cause this trigger to fire.
     */
    @JvmName("cmhbuwdxwcumlfxr")
    public suspend fun events(vararg values: Either<String, BlobEventTypes>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.events = mapped
    }

    /**
     * @param value If set to true, blobs with zero bytes will be ignored.
     */
    @JvmName("gaeliewlrlbkmkoc")
    public suspend fun ignoreEmptyBlobs(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ignoreEmptyBlobs = mapped
    }

    /**
     * @param value Pipelines that need to be started.
     */
    @JvmName("erpuoyregqseyxpk")
    public suspend fun pipelines(`value`: List<TriggerPipelineReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pipelines = mapped
    }

    /**
     * @param argument Pipelines that need to be started.
     */
    @JvmName("dxnqresscaljicky")
    public suspend
    fun pipelines(argument: List<suspend TriggerPipelineReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TriggerPipelineReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.pipelines = mapped
    }

    /**
     * @param argument Pipelines that need to be started.
     */
    @JvmName("jdquixtngngixril")
    public suspend fun pipelines(
        vararg
        argument: suspend TriggerPipelineReferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TriggerPipelineReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.pipelines = mapped
    }

    /**
     * @param argument Pipelines that need to be started.
     */
    @JvmName("oviaapywbjwoxauc")
    public suspend fun pipelines(argument: suspend TriggerPipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            TriggerPipelineReferenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.pipelines = mapped
    }

    /**
     * @param values Pipelines that need to be started.
     */
    @JvmName("djyuyuqdbrcgypbd")
    public suspend fun pipelines(vararg values: TriggerPipelineReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pipelines = mapped
    }

    /**
     * @param value The ARM resource ID of the Storage Account.
     */
    @JvmName("ppjrlmgenknxqphb")
    public suspend fun scope(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scope = mapped
    }

    /**
     * @param value Trigger type.
     * Expected value is 'BlobEventsTrigger'.
     */
    @JvmName("ngtacnchotjipawc")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): BlobEventsTriggerArgs = BlobEventsTriggerArgs(
        annotations = annotations,
        blobPathBeginsWith = blobPathBeginsWith,
        blobPathEndsWith = blobPathEndsWith,
        description = description,
        events = events ?: throw PulumiNullFieldException("events"),
        ignoreEmptyBlobs = ignoreEmptyBlobs,
        pipelines = pipelines,
        scope = scope ?: throw PulumiNullFieldException("scope"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
